# Welcome to geoagent


[![image](https://img.shields.io/pypi/v/geoagent.svg)](https://pypi.python.org/pypi/geoagent)


**AI Agent for geospatial data analysis and visualiation**


-   Free software: MIT License
-   Documentation: <https://opengeos.github.io/geoagent>


## Features

-   TODO
